@@ -6,7 +6,7 @@ import csv
 from typing import List
 
 from reportmix.exporter import Exporter
-from reportmix.models.issue import Issue
+from reportmix.models.report import Report
 
 
 class CsvExporter(Exporter):
@@ -14,10 +14,10 @@ class CsvExporter(Exporter):
     Export a merged report to a CSV file.
     """
 
-    def export(self, output_file: str, issues: List[Issue], fields: List[str]):
+    def export(self, report: Report, output_file: str, fields: List[str]):
         with open(output_file, "w", newline='', encoding='utf-8') as file:
             writer = csv.DictWriter(file, fieldnames=fields, extrasaction='ignore',
                                     delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
             writer.writeheader()
-            for issue in issues:
+            for issue in report.issues:
                 writer.writerow(issue.flatten())
