@@ -6,7 +6,7 @@ import json
 from typing import List
 
 from reportmix.exporter import Exporter
-from reportmix.models.issue import Issue
+from reportmix.models.report import Report
 
 
 class JsonExporter(Exporter):
@@ -14,6 +14,6 @@ class JsonExporter(Exporter):
     Export a merged report to a JSON file.
     """
 
-    def export(self, output_file: str, issues: List[Issue], fields: List[str]):
+    def export(self, report: Report, output_file: str, fields: List[str]):
         with open(output_file, "w") as file:
-            json.dump([i.to_dict() for i in issues], file, default=str)
+            json.dump([i.to_dict() for i in report.issues], file, default=str)
